# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:permissions) do
  include EasyType

  desc <<-DESCR
  The permissions the specified collaborator has on the repo.

      github_collaborator { '...':
        ...
        permissions => 'pull',
        ...
      }

  DESCR

  data_type("Optional[Enum['admin', 'push', 'pull']]")

  newvalues(:admin, :push, :pull)

  to_translate_to_resource do |raw_resource|
    if raw_resource[:permissions][:admin]
      'admin'
    elsif raw_resource[:permissions][:push]
      'push'
    elsif raw_resource[:permissions][:pull]
      'pull'
    else
      fail 'invalid access rights passed from API.'
    end
  end
end
