# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'easy_type'
require 'puppet/property/boolean'

# New puppet type
module Puppet
  Type.newtype(:github_credentials) do
    include EasyType::YamlType

    config_file '/etc/github_credentials.yaml'

    desc <<-DESCR
      Specfies the credentials to use when connecting to github.

      Here is an example on how to use this:

          github_credentials { 'user':
            ensure   => 'present',
            password => 'very_secret',
            username => 'github_username',
          }

      You can use multiple accounts. I that case all github puppet types will
      fetch informations from all accounts.

    DESCR

    ensurable

    parameter :name
    property :username
    property :password
  end
end
