# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newparam(:name) do
  include EasyType
  include EasyType::Validators::Name

  desc <<-DESCR
  The full name of the deploy key. The full name consists of the

  - autorisation
  - owner
  - repo name
  - key name

  Here is an example:

      github_deploy_key { 'autorisation/owner/repo_name:key_name':
        ...
      }

  Puppet will map these values to the right puppet parameters.

  DESCR

  data_type('Optional[String[1]]')

  isnamevar

  to_translate_to_resource do |raw_resource|
    repo  = raw_resource[:repo]
    title = raw_resource[:title]
    "#{repo}:#{title}"
  end
end
