# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newparam(:name) do
  include EasyType
  include EasyType::Validators::Name

  desc <<-DESCR
  The full name of the hook. The full name of the hook consists of the

  - autorisation
  - owner
  - repo name
  - hook name

  Here is an example:

      github_hook { 'autorisation/owner/repo:web':
        ...
      }

  Puppet will map these values to the right puppet parameters.

  DESCR

  data_type('Optional[String[1]]')

  isnamevar

  to_translate_to_resource do |raw_resource|
    repo = raw_resource[:repo]
    name = raw_resource[:name]
    "#{repo}:#{name}"
  end
end
