# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'easy_type'
require 'puppet/property/boolean'
require 'puppet/parameter/boolean'
require 'easy_type/array_property'
require 'puppet_x/enterprisemodules/github/access'

Puppet::Type.newtype(:github_organization) do
  include EasyType
  include Puppet_X::EnterpriseModules::GitHub

  desc <<-DESCR
  Allows you to manage a github organization.

  Here is an example on how to do this:

      github_organization { 'account/organization':
        ensure        => 'present',
        billing_email => 'billing@company.org',
        blog          => 'https://www.enterprisemodules.com',
        description   => 'A github organization',
        email         => 'info@company.org',
        location      => 'The Netherlands',
      }

  DESCR

  ensurable

  to_get_raw_resources do
    values = []
    with_all_credentials do |credentials|
      Puppet.debug 'Fetching organizations...'
      values << organizations.collect do |o|
        org = get_organization(o.login)
        org.to_h.merge!(:name => "#{credentials}/#{o[:login]}")
      end
    end
    values.flatten
  end

  on_create do
    Puppet.warning 'Creating github_organizations through Puppet not supported by API.'
  end

  on_modify do
    authenticated_with(credentials) do
      modify_organization(organization, options)
    end
  end

  on_destroy do
    Puppet.warning 'deleting github_organizations through Puppet not supported by API.'
  end

  map_titles_to_attributes([%r{((.*)/(.*))}, [:name, :credentials, :organization]])

  parameter :name
  parameter :credentials
  parameter :organization

  property :description
  property :company
  property :blog
  property :location
  property :email
  property :billing_email
  property :plan
  # property :members # Experimental

  private

  def options
    value = {}
    value[:description] = description if description
    value[:company] = company if company
    value[:blog] = blog if blog
    value[:location] = location if location
    value[:email] = email if email
    value[:billing_email] = billing_email if billing_email
    value[:plan] = plan if plan
    value
  end
end
