# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newparam(:really_delete, :parent => Puppet::Parameter::Boolean) do
  include EasyType

  desc <<-DESCR
    set thir parameter to true if you want toi **REALLY** delete the repo and its
    contents when it is set to `absent`.

    This example will ony signal a warning:

        github_repo { 'test/allow_delete':
          ensure => absent'
        }

    But this one will **REALY** delete the repo and all of its contents:

        github_repo { 'test/allow_delete':
          ensure        => absent',
          really_delete => true,
        }

    The default is `false` menaing we will **NOT** delete the repo. Use with care!!

  DESCR

  data_type('Optional[Boolean]')

  defaultto false
end
