# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:members, :array_matching => :all) do
  include Puppet_X::EnterpriseModules::GitHub
  include EasyType::ArrayProperty
  include EasyType

  desc <<-DESCR

  An array containing the login names of the members of the team. Here is an example:

      github_team { '...':
        ...
        members     => ['jim', 'spock', 'checkov']
        ...
      }

  DESCR

  data_type('Optional[Variant[String[1],Array[String[1]]]]')

  on_apply do
    members_to_add.each do |member|
      add_team_membership(provider.id, member)
    end
    members_to_remove.each do |member|
      remove_team_membership(provider.id, member)
    end
    nil
  end

  to_translate_to_resource do |raw_resource|
    id = raw_resource[:id]
    team = raw_resource[:name].split('/').last
    Puppet.debug "Fetching members for #{team} "
    team_members(id).collect(&:login)
  end

  private

  def members_to_remove
    provider.members - resource.members
  end

  def members_to_add
    resource.members - provider.members
  end
end
