# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'easy_type'
require 'puppet/property/boolean'
require 'puppet/parameter/boolean'
require 'easy_type/array_property'
require 'puppet_x/enterprisemodules/github/access'

Puppet::Type.newtype(:github_team_repo) do
  include EasyType
  include Puppet_X::EnterpriseModules::GitHub

  desc <<-DESCR

  Allows you to manage the repo's that are visible by team memembers. Here is an
  example on how to add a repository to a team.

      github_team_repo { 'acount/organization/team:owner/repo':
        ensure      => 'present',
        permissions => 'pull',
      }

  DESCR

  ensurable

  to_get_raw_resources do
    values = []
    with_all_credentials do |credentials|
      Puppet.debug 'Fetching organizations...'
      values << organizations.collect do |o|
        org_name = o.login
        Puppet.debug "Fetching teams for #{org_name}"
        organization_teams(org_name).collect do |team|
          Puppet.debug "Fetching repositories for teams for #{team.name}"
          team_repositories(team.id).collect { |e| e.to_hash.merge(:id => team.id, :name => "#{credentials}/#{org_name}/#{team.name}:#{e.full_name}") }
        end
      end
    end
    values.flatten
  end

  on_create do
    authenticated_with(credentials) do
      add_team_repository(provider.id, repository, permissions)
    end
  end

  on_modify do
    authenticated_with(credentials) do
      add_team_repository(provider.id, repository, permissions)
    end
  end

  on_destroy do
    authenticated_with(credentials) do
      remove_team_repository(provider.id, repository, options)
    end
  end

  map_titles_to_attributes([%r{((.*)/(.*)/(.*):(.*))}, [:name, :credentials, :organization, :team, :repository]])

  parameter :id
  parameter :name
  parameter :credentials
  parameter :organization
  parameter :team
  parameter :repository

  property  :permissions

  private

  # def options
  #   value = {}
  #   value[:description] = description if description
  #   value[:privacy] = privacy if privacy
  #   value
  # end
end
